@@ -34,6 +34,10 @@ from .utils import (
     sizeof_fmt,
 )
 
+__author__ = "Samuel Bradley"
+__email__ = "sam.bradley@csiro.au"
+__version__ = "0.9.1"
+
 
 def create_app(
     env_path: str = None,
@@ -55,7 +59,6 @@ def create_app(
 
     # CORS
     origins = []
-
     # Set all CORS enabled origins
     if settings.BACKEND_CORS_ORIGINS:
         origins_raw = settings.BACKEND_CORS_ORIGINS
@@ -71,12 +74,12 @@ def create_app(
             allow_headers=["*"],
         )
 
+    setup_exception_handlers(app)
+
     # Adds support for GZIP response
     if not disable_gzip:
         app.add_middleware(GZipMiddleware, minimum_size=5000)
 
-    setup_exception_handlers(app)
-
     @app.on_event("startup")
     async def on_start_app() -> None:
         await start_app(app)
