@@ -105,7 +105,9 @@ async def decode_token(auth: str):
     raise UnauthorizedError(detail="Unable to find appropriate key",)
 
 
-async def get_user(payload: dict, token: str) -> Optional[AuthUser]:
+async def get_user(
+    payload: dict, token: str, get_profile: bool = True
+) -> Optional[AuthUser]:
     user: Optional[AuthUser] = None
     token_scopes: List[str] = []
 
@@ -114,7 +116,8 @@ async def get_user(payload: dict, token: str) -> Optional[AuthUser]:
 
     if "sub" in payload:
         if (
-            "aud" in payload
+            get_profile
+            and "aud" in payload
             and len(payload["aud"]) > 1
             and "userinfo" in payload["aud"][1]
         ):
@@ -138,10 +141,30 @@ async def get_user(payload: dict, token: str) -> Optional[AuthUser]:
 async def get_current_user(
     security_scopes: SecurityScopes, token: str = Depends(oauth2_scheme)
 ) -> AuthUser:
-
+    settings = get_settings()
     try:
         payload = await decode_token(token)
-        user = await get_user(payload, token)
+        user = await get_user(payload, token, settings.USE_AUTH0_PROFILE)
+
+    except (JWTError, ValidationError) as e:
+        LOG.error("Could not validate credentials. {}", str(e))
+        raise UnauthorizedError(detail="Could not validate credentials.",)
+
+    if not user:
+        raise UnauthorizedError(detail="Invalid authentication credentials.",)
+
+    for scope in security_scopes.scopes:
+        if scope not in user.scopes:
+            raise ForbiddenError(detail="Not enough permissions",)
+    return user
+
+
+async def get_auth_simple(
+    security_scopes: SecurityScopes, token: str = Depends(oauth2_scheme)
+) -> AuthUser:
+    try:
+        payload = await decode_token(token)
+        user = await get_user(payload, token, False)
 
     except (JWTError, ValidationError) as e:
         LOG.error("Could not validate credentials. {}", str(e))
